Khurshid Alam has proposed merging 
lp:~khurshid-alam/unity-control-center/drop-gnomebg into 
lp:unity-control-center.

Commit message:
* Drop libgnome-desktop for background drawing. Use libunity-settings-daemon 
instead. LP: #1863584

* Update version to 20.04 LTS

Requested reviews:
  Sebastien Bacher (seb128)
Related bugs:
  Bug #1863584 in unity-settings-daemon (Ubuntu): "Drop gnombg for background 
drawing"
  https://bugs.launchpad.net/ubuntu/+source/unity-settings-daemon/+bug/1863584

For more details, see:
https://code.launchpad.net/~khurshid-alam/unity-control-center/drop-gnomebg/+merge/379826

Note it must compiled against new unity-settings-daemon in 
https://code.launchpad.net/~khurshid-alam/unity-settings-daemon/drop-gnomebg/+merge/379825
-- 
Your team Unity Control Center development team is subscribed to branch 
lp:unity-control-center.
=== modified file 'configure.ac'
--- configure.ac	2019-05-01 13:16:51 +0000
+++ configure.ac	2020-02-25 16:05:10 +0000
@@ -139,7 +139,7 @@
 PKG_CHECK_MODULES(SHELL, $COMMON_MODULES libgnome-menu-3.0 gio-unix-2.0 x11
                   polkit-gobject-1 >= $POLKIT_REQUIRED_VERSION)
 PKG_CHECK_MODULES(APPEARANCE_PANEL, $COMMON_MODULES libxml-2.0 gnome-desktop-3.0
-                  gdk-pixbuf-2.0 >= $GDKPIXBUF_REQUIRED_VERSION)
+                  gdk-pixbuf-2.0 >= $GDKPIXBUF_REQUIRED_VERSION libunity-settings-daemon)
 PKG_CHECK_MODULES(DATETIME_PANEL, $COMMON_MODULES timezonemap geonames
                   polkit-gobject-1 >= $POLKIT_REQUIRED_VERSION)
 PKG_CHECK_MODULES(DISPLAY_PANEL, $COMMON_MODULES libunity-settings-daemon x11)

=== modified file 'debian/rules'
--- debian/rules	2019-09-02 14:41:58 +0000
+++ debian/rules	2020-02-25 16:05:10 +0000
@@ -18,6 +18,6 @@
 DEB_DH_MAKESHLIBS_ARGS_libunity-control-center1 += -- -c4
 
 binary-post-install/unity-control-center::
-	./panels/info/logo-generator --logo panels/info/UbuntuLogoBlank.png --text "ubuntu 19.10" --output debian/unity-control-center/usr/share/unity-control-center/ui/UbuntuLogo.png
+	./panels/info/logo-generator --logo panels/info/UbuntuLogoBlank.png --text "ubuntu 20.04 LTS" --output debian/unity-control-center/usr/share/unity-control-center/ui/UbuntuLogo.png
 
 common-binary-post-install-arch:: list-missing

=== modified file 'panels/appearance/cc-appearance-item.c'
--- panels/appearance/cc-appearance-item.h	2013-12-02 02:45:53 +0000
+++ panels/appearance/cc-appearance-item.h	2020-02-25 16:05:10 +0000
@@ -20,11 +20,13 @@
 #ifndef __CC_APPEARANCE_ITEM_H
 #define __CC_APPEARANCE_ITEM_H
 
+#define GNOME_DESKTOP_USE_UNSTABLE_API
+
 #include <glib-object.h>
 
 #include <libgnome-desktop/gnome-desktop-thumbnail.h>
+#include <libunity-settings-daemon/gsd-bg.h>
 #include <gdesktop-enums.h>
-#include <libgnome-desktop/gnome-bg.h>
 
 G_BEGIN_DECLS
 

--- panels/appearance/cc-appearance-item.c	2018-02-16 13:02:27 +0000
+++ panels/appearance/cc-appearance-item.c	2020-02-25 16:05:10 +0000
@@ -26,7 +26,7 @@
 #include <gio/gio.h>
 #include <glib/gi18n-lib.h>
 
-#include <libgnome-desktop/gnome-bg.h>
+#include <libunity-settings-daemon/gsd-bg.h>
 #include <gdesktop-enums.h>
 
 #include "cc-appearance-item.h"
@@ -51,7 +51,7 @@
         CcAppearanceItemFlags flags;
 
         /* internal */
-        GnomeBG         *bg;
+        GsdBG         *bg;
         char            *mime_type;
         int              width;
         int              height;
@@ -105,7 +105,7 @@
 		filename = g_file_get_path (file);
 		g_object_unref (file);
 
-		gnome_bg_set_filename (item->priv->bg, filename);
+		gsd_bg_set_filename (item->priv->bg, filename);
 		g_free (filename);
 	}
 
@@ -116,8 +116,8 @@
                 gdk_rgba_parse (&scolor, item->priv->secondary_color);
         }
 
-        gnome_bg_set_rgba (item->priv->bg, item->priv->shading, &pcolor, &scolor);
-        gnome_bg_set_placement (item->priv->bg, item->priv->placement);
+        gsd_bg_set_rgba (item->priv->bg, item->priv->shading, &pcolor, &scolor);
+        gsd_bg_set_placement (item->priv->bg, item->priv->placement);
 }
 
 
@@ -130,7 +130,7 @@
 
         changes = FALSE;
         if (item->priv->bg != NULL) {
-                changes = gnome_bg_changes_with_time (item->priv->bg);
+                changes = gsd_bg_changes_with_time (item->priv->bg);
         }
         return changes;
 }
@@ -144,7 +144,7 @@
 	if (item->priv->uri == NULL) {
 		item->priv->size = g_strdup ("");
 	} else {
-		if (gnome_bg_has_multiple_sizes (item->priv->bg) || gnome_bg_changes_with_time (item->priv->bg)) {
+		if (gsd_bg_has_multiple_sizes (item->priv->bg) || gsd_bg_changes_with_time (item->priv->bg)) {
 			item->priv->size = g_strdup (_("multiple sizes"));
 		} else {
 			/* translators: 100 × 100px
@@ -157,14 +157,14 @@
 }
 
 static GdkPixbuf *
-render_at_size (GnomeBG *bg,
+render_at_size (GsdBG *bg,
                 gint width,
                 gint height)
 {
         GdkPixbuf *pixbuf;
 
         pixbuf = gdk_pixbuf_new (GDK_COLORSPACE_RGB, FALSE, 8, width, height);
-        gnome_bg_draw (bg, pixbuf, gdk_screen_get_default (), FALSE);
+        gsd_bg_draw (bg, pixbuf, gdk_screen_get_default (), FALSE);
 
         return pixbuf;
 }
@@ -189,21 +189,21 @@
                 /* FIXME: this doesn't play nice with slideshow stepping at all,
                  * because it will always render the current slideshow frame, which
                  * might not be what we want.
                  * We're lacking an API to draw a high-res GnomeBG manually choosing
                  * the slideshow frame though, so we can't do much better than this
                  * for now.
                  */
                 pixbuf = render_at_size (item->priv->bg, width, height);
         } else {
                 if (frame >= 0) {
-                        pixbuf = gnome_bg_create_frame_thumbnail (item->priv->bg,
+                        pixbuf = gsd_bg_create_frame_thumbnail (item->priv->bg,
                                                                   thumbs,
                                                                   gdk_screen_get_default (),
                                                                   width,
                                                                   height,
                                                                   frame);
                 } else {
-                        pixbuf = gnome_bg_create_thumbnail (item->priv->bg,
+                        pixbuf = gsd_bg_create_thumbnail (item->priv->bg,
                                                             thumbs,
                                                             gdk_screen_get_default (),
                                                             width,
@@ -213,7 +213,7 @@
 
         if (pixbuf != NULL
             && frame != -2
-            && gnome_bg_changes_with_time (item->priv->bg)) {
+            && gsd_bg_changes_with_time (item->priv->bg)) {
                 GEmblem *emblem;
 
                 emblem = get_slideshow_icon ();
@@ -224,7 +224,7 @@
                 icon = G_ICON (pixbuf);
 	}
 
-        gnome_bg_get_image_size (item->priv->bg,
+        gsd_bg_get_image_size (item->priv->bg,
                                  thumbs,
                                  width,
                                  height,
@@ -734,7 +734,7 @@
 {
         item->priv = CC_APPEARANCE_ITEM_GET_PRIVATE (item);
 
-        item->priv->bg = gnome_bg_new ();
+        item->priv->bg = gsd_bg_new ();
 
         item->priv->shading = G_DESKTOP_BACKGROUND_SHADING_SOLID;
         item->priv->placement = G_DESKTOP_BACKGROUND_STYLE_SCALED;
@@ -189,21 +189,21 @@
                  * because it will always render the current slideshow frame, which
                  * might not be what we want.
-                 * We're lacking an API to draw a high-res GnomeBG manually choosing
+                 * We're lacking an API to draw a high-res GsdBG manually choosing
                  * the slideshow frame though, so we can't do much better than this
                  * for now.

=== modified file 'panels/appearance/cc-appearance-item.h'
-- 
ubuntu-desktop mailing list
ubuntu-desktop@lists.ubuntu.com
https://lists.ubuntu.com/mailman/listinfo/ubuntu-desktop

Reply via email to